@@ -1,4 +1,5 @@
 from gi.repository import Gtk, Gd
+from gettext import gettext as _
 
 
 class Searchbar(Gd.Revealer):
@@ -26,17 +27,10 @@ class Searchbar(Gd.Revealer):
         if self._search_entry.get_property("visible"):
             search_string = self._search_entry.get_text().lower()
             media = model.get_value(itr, 5)
-            searchable_fields = []
-            artist = None
+            searchable_fields = [model.get_value(itr, 2),
+                                 model.get_value(itr, 3)]
             if media and media.get_url():
-                artist = media.get_artist()
-            if media and artist:
-                searchable_fields = [media.get_artist(),
-                                     media.get_album(),
-                                     media.get_title()]
-            else:
-                searchable_fields = [model.get_value(itr, 2),
-                                     model.get_value(itr, 3)]
+                searchable_fields.append(media.get_title())
             for field in searchable_fields:
                 if field and search_string in field.lower():
                     return True
